@@ -36,6 +36,20 @@ class CloudPods:
         self.__session = self.__get_session()
         self.__endpoints = self.__get_endpoint()
         self.__compute_url = f"{self.__endpoints['region2']}/"
+        self.__sku = {
+            1: [1, 2, 4, 8],
+            2: [2, 4, 8, 12, 16],
+            4: [4, 12, 16, 24, 32],
+            8: [8, 16, 24, 32, 64],
+            12: [12, 16, 24, 32, 64],
+            16: [16, 24, 32, 48, 64],
+            24: [24, 32, 48, 64, 128],
+            32: [32, 48, 64, 128]
+        }
+
+    @property
+    def sku(self):
+        return self.__sku
 
     @enter_and_leave_function
     def __get_session(self):
